@@ -16,7 +16,7 @@ import fnmatch
 USER_HOME=os.path.expanduser('~')
 STORE_HOME=USER_HOME+'/.store'
 STORE_TMP_DIR='/.store/.tmp'
-SCRIPTS_PATH='/.freehub-scripts'
+# SCRIPTS_PATH='/.freehub-scripts'
 # BRANCH_LIST_DIR=STORE_HOME+'/BranchLists'
 # SHADOW_STORE_HOME=STORE_HOME+'/ShadowStores'
 # STORE_TMP_DIR=STORE_HOME+'/tmp'
@@ -109,13 +109,13 @@ def get_repo_url(repo_address:str):
 
 
 
-def download_branch(remote_location,branch,dst,overwrite=False):
+def download_branch(remote_location,branch,dst,overwrite=False,quiet=True):
     check_and_make_empty_dir(dst,overwrite)
     repo=git_ops.git_init(dst)
     git_ops.create_head(repo)
-    git_ops.pull_remote_branch(repo,remote_location,branch)
+    git_ops.pull_remote_branch(repo,remote_location,branch,quiet=quiet)
 
-def upload_branch(repo,remote_location,branch,overwrite=False):
+def upload_branch(repo,remote_location,branch,overwrite=False,quiet=True):
     if git_ops.exists_remote_branch(remote_location,branch):
         if not overwrite:
             raise Exception('Remote branch %s already exists at %s .'%(branch,remote_location))
@@ -126,20 +126,20 @@ def upload_branch(repo,remote_location,branch,overwrite=False):
     branches=git_ops.list_branch(repo)
     if not branch in branches:
         raise Exception('Local branch %s does not exist.'%(branch))
-    git_ops.push_local_branch(repo, branch, remote_location)
+    git_ops.push_local_branch(repo, branch, remote_location,quiet=quiet)
 
 
-def download_branch_to_cache(remote_location,branch,cache_dir=None,overwrite=True):
+def download_branch_to_cache(remote_location,branch,cache_dir=None,overwrite=True,**kwargs):
     cache_dir=cache_dir or os.path.join(STORE_HOME,branch)
     check_and_make_empty_dir(cache_dir,overwrite=True)
-    download_branch(remote_location,branch,dst=cache_dir,overwrite=overwrite)
+    download_branch(remote_location,branch,dst=cache_dir,overwrite=overwrite,**kwargs)
     return cache_dir
-def download_branch_to_dir(remote_location,branch,dst,cache_dir=None,overwrite=True):
+def download_branch_to_dir(remote_location,branch,dst,cache_dir=None,overwrite=True,**kwargs):
     cache_dir=cache_dir or os.path.join(STORE_HOME,branch)
-    download_branch_to_cache(remote_location,branch,cache_dir,overwrite=overwrite)
+    download_branch_to_cache(remote_location,branch,cache_dir,overwrite=overwrite,**kwargs)
     copy_repo_files_to_dir(cache_dir,dst)
 
-def upload_to_remote(remote_location,branch_name,relative_path,src_path,cache_dir=None,overwrite=True):
+def upload_to_remote(remote_location,branch_name,relative_path,src_path,cache_dir=None,overwrite=True,**kwargs):
     ''''''
     cache_dir = cache_dir or os.path.join(STORE_HOME, branch_name)
     check_and_make_empty_dir(cache_dir,overwrite=True)
@@ -159,14 +159,14 @@ def upload_to_remote(remote_location,branch_name,relative_path,src_path,cache_di
     git_ops.stage_all_changes(repo)
     git_ops.commit_current_branch(repo)
     try:
-        upload_branch(repo,remote_location,branch_name,overwrite=overwrite)
+        upload_branch(repo,remote_location,branch_name,overwrite=overwrite,**kwargs)
     except GitProtocolError as e:
         logging.error('Error occurred. Might be the permission problem, please check if you have the permission.')
         raise e
 
 
 
-def freehub_download(address,dst_path,overwrite=False):
+def freehub_download(address,dst_path,overwrite=False,**kwargs):
     '''
     {cache_dir}/{relative_path}
     relative_path: can be a path pattern, e.g. *.txt
@@ -174,39 +174,39 @@ def freehub_download(address,dst_path,overwrite=False):
 
     repo_address, branch_name,relative_path=parse_address(address)
     repo_url=get_repo_url(repo_address)
-    cache_dir=download_branch_to_cache(repo_url,branch_name,overwrite=overwrite)
+    cache_dir=download_branch_to_cache(repo_url,branch_name,overwrite=overwrite,**kwargs)
     copy_repo_files_to(cache_dir,relative_path,dst_path,branch_name)
 
 
 
-def freehub_upload(src_path,address,overwrite=False):
+def freehub_upload(src_path,address,overwrite=False,**kwargs):
     repo_address, branch_name,relative_path=parse_address(address)
     repo_url = get_repo_url(repo_address)
-    upload_to_remote(repo_url,branch_name,relative_path,src_path,overwrite=overwrite)
-def fetch(address):
+    upload_to_remote(repo_url,branch_name,relative_path,src_path,overwrite=overwrite,**kwargs)
+def fetch(address,**kwargs):
     repo_address, branch_name, relative_path = parse_address(address)
     repo_url = get_repo_url(repo_address)
-    cache_dir = download_branch_to_cache(repo_url, branch_name, overwrite=True)
+    cache_dir = download_branch_to_cache(repo_url, branch_name, overwrite=True,**kwargs)
     path = join_path(cache_dir, relative_path)
     return path
-def freehub_run(address):
+def freehub_run(address,**kwargs):
     ''''''
     repo_address, branch_name, relative_path = parse_address(address)
     repo_url = get_repo_url(repo_address)
-    cache_dir = download_branch_to_cache(repo_url, branch_name, overwrite=True)
+    cache_dir = download_branch_to_cache(repo_url, branch_name, overwrite=True,**kwargs)
     script_path=join_path(cache_dir,relative_path)
     os.system(script_path)
-def freehub_cat(address:str):
+def freehub_cat(address:str,**kwargs):
     repo_address, branch_name, relative_path = parse_address(address)
     repo_url = get_repo_url(repo_address)
-    cache_dir = download_branch_to_cache(repo_url, branch_name, overwrite=True)
+    cache_dir = download_branch_to_cache(repo_url, branch_name, overwrite=True,**kwargs)
     file_path = join_path(cache_dir, relative_path)
     with open(file_path,'r') as f:
         print(address.center(100,'*'))
         print(f.read())
         print(('End of %s'%(address)).center(100, '*'))
 
-def freehub_search(pattern: str):
+def freehub_search(pattern: str,**kwargs):
     '''
     :param reg_str: [[{host}/]{username}/]{repo_name}[:{branch_name}]
     :return:
@@ -215,7 +215,7 @@ def freehub_search(pattern: str):
     repo_address, branch_name_pattern, relative_path_pattern = parse_address(pattern)
     repo_url = get_repo_url(repo_address)
     assert relative_path_pattern != '/'
-    cache_dir = download_branch_to_cache(repo_url, branch_name_pattern, overwrite=True)
+    cache_dir = download_branch_to_cache(repo_url, branch_name_pattern, overwrite=True,**kwargs)
     fs = glob.glob(join_path(cache_dir, relative_path_pattern), recursive=True)
     for f in fs:
         rel_path = get_relative_path(cache_dir, f)
@@ -253,7 +253,7 @@ def freehub_logout():
 
 
 def test():
-    default_remote_location = FREEHUB_LOCATION
+    default_remote_location = ''
     repo_path = '../data/OpenGitspace'
     import wk
     wk.remake(repo_path)
