@@ -106,8 +106,8 @@ def fetch_remote_branch():
 none_stream = porcelain.NoneStream()
 
 
-def pull_remote_branch(repo, remote_location, branch, quite=True):
-    if quite:
+def pull_remote_branch(repo, remote_location, branch, quiet=True):
+    if quiet:
         porcelain.pull(repo, remote_location, branch,
                        outstream=none_stream, errstream=none_stream
                        )
@@ -116,9 +116,9 @@ def pull_remote_branch(repo, remote_location, branch, quite=True):
                        )
 
 
-def push_local_branch(repo, branch, remote_location, quite=True):
+def push_local_branch(repo, branch, remote_location, quiet=True):
     '''local branch must be same with remote branch?'''
-    if quite:
+    if quiet:
         porcelain.push(repo, remote_location, branch,
                        outstream=none_stream, errstream=none_stream
                        )
